@@ -1,13 +1,14 @@
-import sys
-
 import click
 
-from ogc import state
-from ogc.actions import teardown
+from ogc import actions, db, state
 
 from ..provision import choose_provisioner
 from .base import cli
 
+if not state.app.engine:
+    state.app.engine = db.connect()
+    state.app.session = db.session(state.app.engine)
+
 
 @click.command(help="Destroys a node and its associated keys, storage, etc.")
 @click.option("--name", multiple=True, required=True)
@@ -16,8 +17,13 @@ from .base import cli
     default=False,
     help="Force removal regardless of connectivity",
 )
-def rm(name, force):
-    teardown(name, env=state.app.env, force=force)
+@click.option(
+    "--only-db/--no-only-db",
+    default=False,
+    help="Force removal of database records only",
+)
+def rm(name, force, only_db):
+    actions.teardown_async(name, force=force, only_db=only_db)
 
 
 @click.command(help="Destroys everything. Use with caution.")
@@ -26,8 +32,15 @@ def rm(name, force):
     default=False,
     help="Force removal regardless of connectivity",
 )
-def rm_all(force):
-    teardown(env=state.app.env, force=force)
+@click.option(
+    "--only-db/--no-only-db",
+    default=False,
+    help="Force removal of database records only",
+)
+def rm_all(force, only_db):
+    with state.app.session as session:
+        names = [node.instance_name for node in session.query(db.Node).all()]
+        actions.teardown_async(names, force=force, only_db=only_db)
 
 
 @click.option("--provider", default="aws", help="Provider to query")
