@@ -1,3 +1,4 @@
+import json
 import signal
 import sys
 from pathlib import Path
@@ -7,24 +8,17 @@ from melddict import MeldDict
 from slugify import slugify
 
 from ogc import db
+from ogc.exceptions import SpecLoaderException
 
 from .state import app
 
 
-class SpecLoader(MeldDict):
-    @classmethod
-    def load(cls, specs):
-        cl = SpecLoader()
-        for spec in specs:
-            cl += yaml.load(spec.read_text(), Loader=yaml.FullLoader)
-        return SpecProvisionPlan(cl)
-
-
 class SpecProvisionLayout:
     def __init__(self, layout, env, ssh):
         self.name, self.layout = layout
         self.env = env
         self.ssh = ssh
+        self._scale = self.layout.get("scale", 1)
 
     def __repr__(self):
         return f"<SpecProvisionLayout [{self.name}]>"
@@ -55,7 +49,11 @@ class SpecProvisionLayout:
 
     @property
     def scale(self):
-        return self.layout.get("scale", 1)
+        return self._scale
+
+    @scale.setter
+    def scale(self, val):
+        self._scale = val
 
     @property
     def tags(self):
@@ -102,6 +100,9 @@ class SpecProvisionLayout:
             "ports": self.ports,
         }
 
+    def as_json(self):
+        return json.dumps(self.as_dict())
+
 
 class SpecProvisionSSHKey:
     def __init__(self, sshkeys):
@@ -147,23 +148,23 @@ class SpecProvisionPlan:
     @property
     def status(self):
         """Return the status of the plan based on whats deployed and whats remaining"""
-        db.connect()
-        counts = {
-            layout.name: {"scale": layout.scale, "deployed": 0, "remaining": 0}
-            for layout in self.layouts
-        }
-        for layout in self.layouts:
-            deployed_count = len(
-                db.NodeModel.select().where(
-                    db.NodeModel.instance_name.endswith(layout.name)
+        with app.session as session:
+            counts = {
+                layout.name: {"scale": layout.scale, "deployed": 0, "remaining": 0}
+                for layout in self.layouts
+            }
+            for layout in self.layouts:
+                deployed_count = (
+                    session.query(db.Node)
+                    .filter(db.Node.instance_name.endswith(layout.name))
+                    .count()
                 )
-            )
-            remaining_count = layout.scale - deployed_count
-            action = "add" if remaining_count >= 0 else "remove"
-            counts[layout.name]["deployed"] = deployed_count
-            counts[layout.name]["remaining"] = remaining_count
-            counts[layout.name]["action"] = action
-        return counts
+                remaining_count = layout.scale - deployed_count
+                action = "add" if remaining_count >= 0 else "remove"
+                counts[layout.name]["deployed"] = deployed_count
+                counts[layout.name]["remaining"] = remaining_count
+                counts[layout.name]["action"] = action
+            return counts
 
     @property
     def is_degraded(self):
@@ -173,6 +174,20 @@ class SpecProvisionPlan:
             for stat in self.status.values()
         )
 
+    @property
+    def is_deployed(self):
+        """Returns whether there are any deployments at all"""
+        return any(stat["deployed"] > 0 for stat in self.status.values())
+
+    @property
+    def deploy_status(self):
+        status_text = "[bold green]Healthy[/]"
+        if self.is_degraded and self.is_deployed:
+            status_text = "[bold red]Degraded[/]"
+        elif not self.is_deployed:
+            status_text = "Idle"
+        return status_text
+
     def get_layout(self, name):
         """Returns a layout for a given name/key"""
         return [layout for layout in self.layouts if layout.name == name]
@@ -184,3 +199,27 @@ class SpecProvisionPlan:
         self.force_shutdown = True
         app.log.debug(f"Caught signal {sig} - {frame}")
         sys.exit(1)
+
+
+class SpecLoader(MeldDict):
+    @classmethod
+    def load(cls, specs: list[str]) -> "SpecProvisionPlan":
+        if Path("ogc.yml").exists():
+            specs.insert(0, "ogc.yml")
+
+        _specs = []
+        for sp in specs:
+            _path = Path(sp)
+            if not _path.exists():
+                raise SpecLoaderException(f"Could not find {_path}")
+            _specs.append(_path)
+
+        if not _specs:
+            raise SpecLoaderException(
+                f"No provision specs found, please specify with `--spec <file.yml>`"
+            )
+
+        cl = SpecLoader()
+        for spec in _specs:
+            cl += yaml.load(spec.read_text(), Loader=yaml.FullLoader)
+        return SpecProvisionPlan(cl)
